==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/en_GB.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendar",
    "%s has published the calendar \"%s\"" : "%s has published the calendar \"%s\"",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "The remote server did not give us access to the calendar (HTTP {%s} error)",
    "Error connecting to remote server" : "Error connecting to remote server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error requesting resource on remote server. This could possible be related to a certificate mismatch",
    "Error requesting resource on remote server" : "Error requesting resource on remote server",
    "Individual" : "Individual",
    "Group" : "Group",
    "Resource" : "Resource",
    "Room" : "Room",
    "Unknown" : "Unknown",
    "Required" : "Required",
    "Optional" : "Optional",
    "Does not attend" : "Does not attend",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "You are in an unknown timezone ({tz}), falling back to UTC",
    "Please create a calendar first." : "Please create a calendar first.",
    "New event" : "New event",
    "CalDAV address for clients" : "CalDAV address for clients",
    "Error saving WebCal-calendar" : "Error saving WebCal-calendar",
    "WebDAV address for subscriptions" : "WebDAV address for subscription",
    "EMail has been sent." : "EMail has been sent.",
    "There was an issue while sending your EMail." : "There was an issue while sending your EMail.",
    "group" : "group",
    "Details" : "Details",
    "Attendees" : "Attendees",
    "Reminders" : "Reminders",
    "Repeating" : "Repeating",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "Confirmed" : "Confirmed",
    "Tentative" : "Tentative",
    "Cancelled" : "Cancelled",
    "Please add a title!" : "Please add a title!",
    "Please select a calendar!" : "Please select a calendar!",
    "Global" : "Global",
    "None" : "None",
    "Every day" : "Every day",
    "Every week" : "Every week",
    "Every month" : "Every month",
    "Every year" : "Every year",
    "never" : "never",
    "after" : "after",
    "How about getting started by importing some calendars?" : "How about getting started by importing some calendars?",
    "At time of event" : "At time of event",
    "5 minutes before" : "5 minutes before",
    "10 minutes before" : "10 minutes before",
    "15 minutes before" : "15 minutes before",
    "30 minutes before" : "30 minutes before",
    "1 hour before" : "1 hour before",
    "2 hours before" : "2 hours before",
    "Custom" : "Custom",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Pop-up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "hours",
    "days" : "days",
    "week" : "week",
    "before" : "before",
    "start" : "start",
    "end" : "end",
    "Editing reminders of unknown type not supported." : "Editing reminders of unknown type not supported.",
    "Week {number} of {year}" : "Week {number} of {year}",
    "Successfully imported" : "Successfully imported",
    "Partially imported, 1 failure" : "Partially imported, 1 failure",
    "Partially imported, {n} failures" : "Partially imported, {n} failures",
    "Audio alarm" : "Audio alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "Email",
    "{type} {time} before the event starts" : "{type} {time} before the event starts",
    "{type} {time} before the event ends" : "{type} {time} before the event ends",
    "{type} {time} after the event starts" : "{type} {time} after the event starts",
    "{type} {time} after the event ends" : "{type} {time} after the event ends",
    "{type} at the event's start" : "{type} at the event's start",
    "{type} at the event's end" : "{type} at the event's end",
    "{type} at {time}" : "{type} at {time}",
    "{calendar} shared by {owner}" : "{calendar} shared by {owner}",
    "Please enter a valid WebCal-URL" : "Please enter a valid WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Severe error in webcal proxy. Please contact administrator for more information.",
    "Title of the Event" : "Title of the Event",
    "All day Event" : "All day Event",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "More ..." : "More ...",
    "Create" : "Create",
    "Update" : "Update",
    "Close" : "Close",
    "Location" : "Location",
    "Description" : "Description",
    "Event status" : "Event status",
    "Visibility when sharing" : "Visibility when sharing",
    "Export" : "Export",
    "%s has published the calendar %s" : "%s has published the calendar %s",
    "Hello," : "Hello,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}.",
    "Click here to access it" : "Click here to access it.",
    "Cheers!" : "Cheers!",
    "We wanted to inform you that %s has published the calendar %s." : "We wanted to infrom you that %s has published the calendar %s.",
    "Click on the link below to access it" : "Click on the link below to access it",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option.",
    "Day" : "Day",
    "Week" : "Week",
    "Month" : "Month",
    "Today" : "Today",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Some events in this calendar are broken. Please check the JS console for more info.",
    "Share Calendar" : "Share Calendar",
    "Shared" : "Shared",
    "More" : "More",
    "Edit" : "Edit",
    "Link" : "Link",
    "Download" : "Download",
    "Share with users or groups" : "Share with users or groups",
    "can edit" : "can edit",
    "Share link" : "Share link",
    "Public access" : "Public access",
    "Email link to person" : "Email link to person",
    "Send" : "Send",
    "New Calendar" : "New Calendar",
    "Name" : "Name",
    "New Subscription" : "New Subscription",
    "Go back" : "Go back",
    "Go forward" : "Go forward",
    "Edit event" : "Edit event",
    "Delete Event" : "Delete Event",
    "Save Event" : "Save Event",
    "Time" : "Time",
    "Type" : "Type",
    "Relative" : "Relative",
    "Absolute" : "Absolute",
    "Repeat" : "Repeat",
    "times every" : "times every",
    "Add" : "Add",
    "E-Mail address of attendee" : "E-Mail address of attendee",
    "Please add your email address in the personal settings in order to add attendees." : "Please add your email address in the personal settings in order to add attendees.",
    "from" : "from",
    "to" : "to",
    "This event's repeating rule is not supported yet." : "This event's repeating rule is not supported yet.",
    "Support for advanced rules will be added with subsequent updates." : "Support for advanced rules will be added with subsequent updates.",
    "Reset repeating rule" : "Reset repeating rule",
    "Repeat every ..." : "Repeat every ...",
    "end repeat ..." : "end repeat ...",
    "times" : "times",
    "Import Calendars" : "Import Calendars",
    "Import canceled" : "Import cancelled",
    "Analyzing calendar" : "Analysing calendar",
    "The file contains objects incompatible with the selected calendar" : "The file contains objects incompatible with the selected calendar",
    "New calendar" : "New calendar",
    "File is empty" : "File is empty",
    "Import scheduled" : "Import scheduled",
    "Publish URL" : "Publish URL",
    "Skip simple event editor" : "Skip simple event editor",
    "Show week numbers" : "Show week numbers",
    "Import calendar" : "Import calendar",
    "No Calendars selected for import" : "No Calendars selected for import",
    "Primary CalDAV address" : "Primary CalDAV address",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV address"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/en_GB.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendar",
    "%s has published the calendar »%s«" : "%s has published the calendar »%s«",
    "Hello," : "Hello,",
    "We wanted to inform you that %s has published the calendar »%s«." : "We wanted to inform you that %s has published the calendar »%s«.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Cheers!",
    "Recipient" : "Recipient",
    "Too many redirects. Aborting ..." : "Too many redirects. Aborting ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "The remote server did not give us access to the calendar (HTTP {%s} error)",
    "Error connecting to remote server" : "Error connecting to remote server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error requesting resource on remote server. This could possible be related to a certificate mismatch",
    "Error requesting resource on remote server" : "Error requesting resource on remote server",
    "Individual" : "Individual",
    "Group" : "Group",
    "Resource" : "Resource",
    "Room" : "Room",
    "Unknown" : "Unknown",
    "Required" : "Required",
    "Optional" : "Optional",
    "Does not attend" : "Does not attend",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "You are in an unknown timezone ({tz}), falling back to UTC",
    "Please create a calendar first." : "Please create a calendar first.",
    "New event" : "New event",
    "CalDAV address for clients" : "CalDAV address for clients",
    "Error saving WebCal-calendar" : "Error saving WebCal-calendar",
    "WebDAV address for subscriptions" : "WebDAV address for subscription",
    "Email has been sent." : "Email has been sent.",
    "There was an issue while sending your email." : "There was an issue while sending your email.",
    "group" : "group",
    "Details" : "Details",
    "Attendees" : "Attendees",
    "Reminders" : "Reminders",
    "Repeating" : "Repeating",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "Confirmed" : "Confirmed",
    "Tentative" : "Tentative",
    "Cancelled" : "Cancelled",
    "Please add a title." : "Please add a title.",
    "Please select a calendar." : "Please select a calendar.",
    "The event can not end before it starts." : "The event can not end before it starts.",
    "Global" : "Global",
    "None" : "None",
    "Every day" : "Every day",
    "Every week" : "Every week",
    "Every month" : "Every month",
    "Every year" : "Every year",
    "never" : "never",
    "after" : "after",
    "How about getting started by importing some calendars?" : "How about getting started by importing some calendars?",
    "At time of event" : "At time of event",
    "5 minutes before" : "5 minutes before",
    "10 minutes before" : "10 minutes before",
    "15 minutes before" : "15 minutes before",
    "30 minutes before" : "30 minutes before",
    "1 hour before" : "1 hour before",
    "2 hours before" : "2 hours before",
    "Custom" : "Custom",
    "Audio" : "Audio",
    "Email" : "Email",
    "Pop-up" : "Pop-up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "hours",
    "days" : "days",
    "week" : "week",
    "before" : "before",
    "start" : "start",
    "end" : "end",
    "Editing reminders of unknown type not supported." : "Editing reminders of unknown type not supported.",
    "Week {number} of {year}" : "Week {number} of {year}",
    "Successfully imported" : "Successfully imported",
    "Partially imported, 1 failure" : "Partially imported, 1 failure",
    "Partially imported, {n} failures" : "Partially imported, {n} failures",
    "Audio alarm" : "Audio alarm",
    "{type} {time} before the event starts" : "{type} {time} before the event starts",
    "{type} {time} before the event ends" : "{type} {time} before the event ends",
    "{type} {time} after the event starts" : "{type} {time} after the event starts",
    "{type} {time} after the event ends" : "{type} {time} after the event ends",
    "{type} at the event's start" : "{type} at the event's start",
    "{type} at the event's end" : "{type} at the event's end",
    "{type} at {time}" : "{type} at {time}",
    "{calendar} shared by {owner}" : "{calendar} shared by {owner}",
    "Please enter a valid WebCal-URL" : "Please enter a valid WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Severe error in webcal proxy. Please contact administrator for more information.",
    "Title of the Event" : "Title of the Event",
    "Starts" : "Starts",
    "Ends" : "Ends",
    "All day Event" : "All day Event",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "More ..." : "More ...",
    "Create" : "Create",
    "Update" : "Update",
    "Close" : "Close",
    "Location" : "Location",
    "Description" : "Description",
    "Event status" : "Event status",
    "Visibility when sharing" : "Visibility when sharing",
    "Export" : "Export",
    "%s has published the calendar %s" : "%s has published the calendar %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}.",
    "Click here to access it" : "Click here to access it.",
    "We wanted to inform you that %s has published the calendar %s." : "We wanted to infrom you that %s has published the calendar %s.",
    "Click on the link below to access it" : "Click on the link below to access it",
    "Day" : "Day",
    "Week" : "Week",
    "Month" : "Month",
    "Today" : "Today",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Some events in this calendar are broken. Please check the JS console for more info.",
    "Share Calendar" : "Share Calendar",
    "Shared" : "Shared",
    "More" : "More",
    "Edit" : "Edit",
    "Link" : "Link",
    "iCal link" : "iCal link",
    "Download" : "Download",
    "Share with users or groups" : "Share with users or groups",
    "can edit" : "can edit",
    "Share link" : "Share link",
    "Public access" : "Public access",
    "Email link to person" : "Email link to person",
    "Send" : "Send",
    "New Calendar" : "New Calendar",
    "Name" : "Name",
    "New Subscription" : "New Subscription",
    "Go back" : "Go back",
    "Go forward" : "Go forward",
    "Calendar does not exist" : "Calendar does not exist",
    "Maybe you got a wrong link or the calendar was unshared?" : "Maybe you got a wrong link or the calendar was unshared?",
    "Edit event" : "Edit event",
    "Delete Event" : "Delete Event",
    "Save Event" : "Save Event",
    "Time" : "Time",
    "Type" : "Type",
    "Relative" : "Relative",
    "Absolute" : "Absolute",
    "Repeat" : "Repeat",
    "times every" : "times every",
    "Add" : "Add",
    "Email address of attendee" : "Email address of attendee",
    "Please add your email address in the personal settings in order to add attendees." : "Please add your email address in the personal settings in order to add attendees.",
    "from" : "from",
    "to" : "to",
    "This event's repeating rule is not supported yet." : "This event's repeating rule is not supported yet.",
    "Support for advanced rules will be added with subsequent updates." : "Support for advanced rules will be added with subsequent updates.",
    "Reset repeating rule" : "Reset repeating rule",
    "Repeat every ..." : "Repeat every ...",
    "end repeat ..." : "end repeat ...",
    "times" : "times",
    "Import Calendars" : "Import Calendars",
    "Import canceled" : "Import cancelled",
    "Analyzing calendar" : "Analysing calendar",
    "The file contains objects incompatible with the selected calendar" : "The file contains objects incompatible with the selected calendar",
    "New calendar" : "New calendar",
    "File is empty" : "File is empty",
    "Import scheduled" : "Import scheduled",
    "%s shared the calendar <strong>%s</strong> with you" : "%s shared the calendar <strong>%s</strong> with you",
    "Embed" : "Embed",
    "Iframe to integrate" : "Iframe to integrate",
    "Publish URL" : "Publish URL",
    "Settings & import" : "Settings & import",
    "Skip simple event editor" : "Skip simple event editor",
    "Show week numbers" : "Show week numbers",
    "Import calendar" : "Import calendar",
    "No Calendars selected for import" : "No Calendars selected for import",
    "Primary CalDAV address" : "Primary CalDAV address",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV address",
    "Subscribe" : "Subscribe"
},
"nplurals=2; plural=(n != 1);");
